@@ -76,7 +76,6 @@
 #'
 #' @importFrom stats uniroot
 #' @export
-#' @useDynLib salso .minimize_by_salso
 #'
 #' @examples
 #' # For examples, use 'nCores=1' per CRAN rules, but in practice omit this.
@@ -150,33 +149,27 @@ salso <- function(x, loss=VI(), maxNClusters=0, nRuns=16, maxZealousAttempts=10,
     probSingletonsInitialization <- dots[["probSingletonsInitialization"]]
     if ( probSingletonsInitialization < 0.0 || probSingletonsInitialization > 1.0 ) stop("'probSingletonsInitialization' should be in [0,1].")
   }
-  seed <- sapply(1:32, function(i) sample.int(256L,1L)-1L)
   if ( ( maxNClusters == 0 ) && ( ! is.null(z$psm) ) && ( ! is.null(z$draws) ) ) {
     maxNClusters <- max(apply(z$draws, 1, function(x) length(unique(x))))
   }
-  y <- .Call(.minimize_by_salso, z$draws, z$psm, z$lossCode, z$a, maxNClusters, nRunsX, seconds, maxScans, maxZealousAttempts, probSequentialAllocation, probSingletonsInitialization, nCores, seed)
-  estimate <- y[[1]]
-  attr(estimate,"info") <- {
-    attr <- y[[2]]
-    names(attr) <- c("loss","a","maxNClusters","expectedLoss","initMethod","nScans","nZAcc","nZAtt","nRuns","seconds")
-    attr$loss <- z$loss
-    if ( ! z$loss %in% c("binder","VI") ) attr$a <- NULL
-    attr$initMethod <- names(which(initMethodMapping==attr$initMethod))
-    as.data.frame(attr, row.names="")
-  }
-  attr(estimate,"draws") <- z$draws
-  attr(estimate,"psm") <- z$psm
-  actualNRuns <- attr(estimate,"info")$nRuns
+  estimate <- .Call(.minimize_by_salso, z$draws, z$psm, z$lossCode, z$a, maxNClusters, nRunsX, seconds, maxScans, maxZealousAttempts, probSequentialAllocation, probSingletonsInitialization, nCores)
+  info <- attr(estimate, "info")
+  info$loss <- z$loss
+  if ( ! z$loss %in% c("binder","VI") ) info$a <- NULL
+  info$initMethod <- names(which(initMethodMapping==info$initMethod))
+  attr(estimate, "info") <- as.data.frame(info, row.names="")
+  attr(estimate, "draws") <- z$draws
+  attr(estimate, "psm") <- z$psm
+  actualNRuns <- info$nRuns
   if ( is.finite(nRuns) && ( actualNRuns < nRunsX ) ) {
     warning(sprintf("Only %s of the requested %s run%s performed. Consider increasing 'seconds' or lowering 'nRuns'.",actualNRuns,nRuns,ifelse(actualNRuns==1L," was","s were")))
   }
-  if ( ( maxNClusters == 0 ) && ( length(unique(estimate)) == attr(estimate,"info")$maxNClusters ) ) {
+  if ( ( maxNClusters == 0 ) && ( length(unique(estimate)) == info$maxNClusters ) ) {
     warning("The number of clusters equals the default maximum possible number of clusters.")
   }
-  if ( ( maxZealousAttempts > 0 ) && ( attr(estimate,"info")$nZAtt > maxZealousAttempts ) ) {
+  if ( ( maxZealousAttempts > 0 ) && ( info$nZAtt > maxZealousAttempts ) ) {
     warning("The number of possible zealous attempts exceeded the maximum. Do you really want that many clusters? Consider lowering 'maxNClusters' or increasing 'maxZealousAttempts'.")
   }
-  class(estimate) <- "salso.estimate"
   estimate
 }
 
